package
Version:
v1.4.3
Opens a new window with list of versions in this module.
Published: Oct 11, 2023
License: BSD-3-Clause
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type HttpOption struct {
Url string `json:"url" msgpack:"url"`
Body map[string]interface{} `json:"body" msgpack:"body"`
}
type Job struct {
Key string `msgpack:"key"`
Index int `msgpack:"index"`
Mode string `msgpack:"mode"`
Option interface{} `msgpack:"option"`
}
type Values struct {
Namespace string `env:"NAMESPACE,required"`
Nats struct {
Hosts []string `env:"HOSTS,required" envSeparator:","`
Nkey string `env:"NKEY,required"`
} `envPrefix:"NATS_"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.